==> arrow-docs-0.8.0-sources.jar: com/example/domain/Company$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Company`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Company`, arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Address`>> inline get()= arrow.optics.Iso(
  get = { company: `com`.`example`.`domain`.`Company` -> arrow.core.Tuple2(company.`name`, company.`address`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Address`> -> `com`.`example`.`domain`.`Company`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Company`.Companion.name: arrow.optics.Lens<`com`.`example`.`domain`.`Company`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { company: `com`.`example`.`domain`.`Company` -> company.`name` },
  set = { value: `kotlin`.`String` ->
    { company: `com`.`example`.`domain`.`Company` ->
      company.copy(`name` = value)
    }
  }
)

inline val `com`.`example`.`domain`.`Company`.Companion.address: arrow.optics.Lens<`com`.`example`.`domain`.`Company`, `com`.`example`.`domain`.`Address`> inline get()= arrow.optics.Lens(
  get = { company: `com`.`example`.`domain`.`Company` -> company.`address` },
  set = { value: `com`.`example`.`domain`.`Address` ->
    { company: `com`.`example`.`domain`.`Company` ->
      company.copy(`address` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Getter<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Setter<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Fold<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address

==> arrow-docs-0.10.4-sources.jar: com/example/domain/Company$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Company`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Company`, arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Address`>> inline get()= arrow.optics.Iso(
  get = { company: `com`.`example`.`domain`.`Company` -> arrow.core.Tuple2(company.`name`, company.`address`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Address`> -> `com`.`example`.`domain`.`Company`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Company`.Companion.name: arrow.optics.Lens<`com`.`example`.`domain`.`Company`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { company: `com`.`example`.`domain`.`Company` -> company.`name` },
  set = { company: `com`.`example`.`domain`.`Company`, value: `kotlin`.`String` -> company.copy(`name` = value) }
)

inline val `com`.`example`.`domain`.`Company`.Companion.address: arrow.optics.Lens<`com`.`example`.`domain`.`Company`, `com`.`example`.`domain`.`Address`> inline get()= arrow.optics.Lens(
  get = { company: `com`.`example`.`domain`.`Company` -> company.`address` },
  set = { company: `com`.`example`.`domain`.`Company`, value: `com`.`example`.`domain`.`Address` -> company.copy(`address` = value) }
)




inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Company`.name

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Getter<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Setter<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`>.address: arrow.optics.Fold<S, `com`.`example`.`domain`.`Address`> inline get() = this + `com`.`example`.`domain`.`Company`.address
